@@ -1,33 +1,35 @@
-import sys
-import re
+"""e2j2 main functions"""
 import argparse
-import os
-import traceback
 import json
+import os
+import re
 import subprocess
+import sys
+import traceback
+from os.path import basename
 from random import uniform as random_uniform
+from stat import ST_MODE
 from subprocess import CalledProcessError
 from threading import Thread
 from time import sleep
-from jsonschema import validate, draft4_format_checker
-from os.path import basename
-from stat import ST_MODE
+
+from jsonschema import Draft4Validator, validate
+
 from e2j2 import templates
-from e2j2.templates import get_vars
-from e2j2.constants import DESCRIPTION, VERSION
-from e2j2.constants import CONFIG_SCHEMAS
+from e2j2.constants import CONFIG_SCHEMAS, DESCRIPTION, VERSION
+from e2j2.display import get_colors, no_colors, write
 from e2j2.exceptions import E2j2Exception
-from e2j2.display import (
-    no_colors,
-    write,
-    get_colors,
-)
+from e2j2.templates import get_vars
+
+
+def repeat():
+    return True
 
 
 def arg_parse(program, description, version):
     arg_parser = argparse.ArgumentParser(prog=program, description=description)
     arg_parser.add_argument(
-        "-v", "--version", action="version", version="%(prog)s {}".format(version)
+        "-v", "--version", action="version", version=f"%(prog)s {version}"
     )
     arg_parser.add_argument(
         "-e",
@@ -124,7 +126,7 @@ def arg_parse(program, description, version):
         "--comment_end",
         type=str,
         help="Comment marker end (default: use marker set)",
-    ),
+    )
     arg_parser.add_argument(
         "--config-start", type=str, help="Config marker start (default: use marker set)"
     )
@@ -159,9 +161,7 @@ def arg_parse(program, description, version):
         help="Include stack trace in error file / show stack trace",
     )
     arg_parser.add_argument(
-        "--stderr",
-        action="store_true",
-        help="Print to stderr instead of to error file"
+        "--stderr", action="store_true", help="Print to stderr instead of to error file"
     )
     arg_parser.add_argument("-c", "--config", type=str, help="config file path")
     arg_parser.add_argument(
@@ -189,7 +189,7 @@ def arg_parse(program, description, version):
     )
     args = arg_parser.parse_args()
 
-    if args.recursive and not args.searchlist and not "E2J2_SEARCHLIST" in os.environ:
+    if args.recursive and not args.searchlist and "E2J2_SEARCHLIST" not in os.environ:
         arg_parser.error("the following arguments are required: searchlist")
 
     if args.splay and not args.watchlist:
@@ -230,9 +230,7 @@ def configure(args):
     config["stacktrace"] = (
         args.stacktrace if args.stacktrace else config.get("stacktrace", False)
     )
-    config["stderr"] = (
-        args.stderr if args.stderr else config.get("stderr", False)
-    )
+    config["stderr"] = args.stderr if args.stderr else config.get("stderr", False)
     config["initial_run"] = (
         args.initial_run if args.initial_run else config.get("initial_run", False)
     )
@@ -300,7 +298,7 @@ def configure(args):
     validate(
         instance=config,
         schema=CONFIG_SCHEMAS["configfile"],
-        format_checker=draft4_format_checker,
+        format_checker=Draft4Validator.FORMAT_CHECKER,
     )
 
     if config["no_color"]:
@@ -312,12 +310,12 @@ def configure(args):
 def get_files(**kwargs):
     if kwargs["filelist"]:
         return kwargs["filelist"]
-    else:
-        return templates.find(
-            searchlist=kwargs["searchlist"],
-            j2file_ext=kwargs["extension"],
-            recurse=kwargs["recurse"],
-        )
+
+    return templates.find(
+        searchlist=kwargs["searchlist"],
+        j2file_ext=kwargs["extension"],
+        recurse=kwargs["recurse"],
+    )
 
 
 def copy_file_permissions(source, destination):
@@ -359,7 +357,7 @@ def run(config):
     for j2file in j2files:
         try:
             directory = os.path.dirname(j2file)
-            filename = re.sub(r"{}$".format(extension), "", j2file)
+            filename = re.sub(rf"{extension}$", "", j2file)
 
             if directory != old_directory:
                 write(
@@ -383,13 +381,15 @@ def run(config):
                 status = f"{colors.green}content"
 
                 if config["stacktrace"]:
-                    content += "\n\n%s" % traceback.format_exc()
+                    content += f"\n\n{traceback.format_exc()}"
 
             if is_error and config["stderr"]:
                 write(f"{colors.red}failed{colors.reset}{'':1}{content}\n")
             else:
                 write(
-                    f"{status:7}{'':1}{colors.green}=> writing{'':1}{colors.white}{basename(filename):35}{'':1}{colors.green}=>{'':1}"
+                    f"{status:7}{'':1}{colors.green}"
+                    f"=> writing{'':1}{colors.white}{basename(filename):35}{'':1}{colors.green}"
+                    f"=>{'':1}"
                 )
 
                 if config["noop"]:
@@ -464,7 +464,7 @@ def watch(config):
     cfg = config.copy()
     cfg["run"] = []
 
-    while True:
+    while repeat():
         try:
             env_data = get_vars(config, config["watchlist"], [])
         except KeyError as err:
@@ -489,7 +489,7 @@ def watch(config):
         first_run = False
 
 
-def e2j2():
+def main():
     exit_code = 0
     args = arg_parse("e2j2", DESCRIPTION, VERSION)
     try:
