@@ -1,5 +1,6 @@
+"display / terminal color handling functions"
 import sys
-from string import Template
+
 from e2j2 import cache
 
 BRIGHT_RED = "\033[1;31m"
@@ -19,27 +20,27 @@ class Colorize:
     white = WHITE
 
 
-_colors = Colorize()
+COLORS = Colorize()
 
 
 def get_colors():
-    return _colors
+    return COLORS
 
 
 def colorize():
-    global _colors
-    _colors = Colorize()
+    global COLORS
+    COLORS = Colorize()
 
 
 def no_colors():
-    global _colors
-    _colors = Colorize()
-    _colors.red = ''
-    _colors.reset = ''
-    _colors.yellow = ''
-    _colors.green = ''
-    _colors.lightgreen = ''
-    _colors.white = ''
+    global COLORS
+    COLORS = Colorize()
+    COLORS.red = ""
+    COLORS.reset = ""
+    COLORS.yellow = ""
+    COLORS.green = ""
+    COLORS.lightgreen = ""
+    COLORS.white = ""
 
 
 def write(msg):
@@ -51,23 +52,9 @@ def write(msg):
         sys.stderr.write(msg)
         cache.log_repeat_log_msg_counter = 0
     elif counter == print_at:
-        sys.stderr.write('({}x) '.format(print_at) + msg)
+        sys.stderr.write(f"({print_at}x) {msg}")
         cache.print_at += increment
         cache.log_repeat_log_msg_counter = 0
 
     cache.log_repeat_log_msg_counter += 1
     cache.last_log_line = msg
-
-
-def display(text):
-    template = Template(text)
-    write(
-        template.substitute(
-            bright_red=_colors.red,
-            green=_colors.green,
-            lightgreen=_colors.lightgreen,
-            white=_colors.white,
-            yellow=_colors.yellow,
-            reset_all=_colors.reset,
-        )
-    )
