@@ -5,6 +5,6 @@ def parse(file_name):
     try:
         with open(file_name) as file_handle:
             return file_handle.read()
-    except IOError:
+    except IOError as err:
         # Mark as failed
-        raise E2j2Exception('IOError raised while reading file: %s' % file_name)
+        raise E2j2Exception(f"IOError raised while reading file: {file_name}") from err
