@@ -1,27 +1,30 @@
-import os
-import sys
-import jinja2
-import re
+"""Template rendering functions"""
 import json
+import os
+import re
+import sys
 import traceback
-from dpath import util as dpath_util
-from jinja2.exceptions import UndefinedError, FilterArgumentError, TemplateSyntaxError
-from jsonschema import validate, ValidationError, draft4_format_checker
 from json.decoder import JSONDecodeError
+
+import jinja2
+import dpath
+from jinja2.exceptions import FilterArgumentError, TemplateSyntaxError, UndefinedError
+from jsonschema import ValidationError, Draft4Validator, validate
+
+from e2j2.constants import CONFIG_SCHEMAS, MARKER_SETS, NESTED_TAGS, TAGS
+from e2j2.display import get_colors, write
 from e2j2.exceptions import E2j2Exception
-from e2j2.constants import CONFIG_SCHEMAS, TAGS, NESTED_TAGS, MARKER_SETS
 from e2j2.tags import (
     base64_tag,
     consul_tag,
+    dns_tag,
+    escape_tag,
     file_tag,
     json_tag,
     jsonfile_tag,
     list_tag,
     vault_tag,
-    dns_tag,
-    escape_tag,
 )
-from e2j2.display import write, get_colors
 
 try:
     from jinja2_ansible_filters import AnsibleCoreFiltersExtension
@@ -51,13 +54,13 @@ def find(searchlist, j2file_ext, recurse=False):
             for j2file in files
             if j2file.endswith(j2file_ext)
         ]
-    else:
-        return [
-            os.path.realpath(os.path.join(searchlist_item, j2file))
-            for searchlist_item in searchlist
-            for j2file in os.listdir(searchlist_item)
-            if j2file.endswith(j2file_ext)
-        ]
+
+    return [
+        os.path.realpath(os.path.join(searchlist_item, j2file))
+        for searchlist_item in searchlist
+        for j2file in os.listdir(searchlist_item)
+        if j2file.endswith(j2file_ext)
+    ]
 
 
 def get_vars(config, whitelist, blacklist):
@@ -98,57 +101,58 @@ def resolv_vars(config, var_list, env_vars):
 
 def parse_tag(config, tag, value):
     tag_config = {}
-    value = re.sub(r"^{}".format(tag), "", value).strip()
-    if tag in CONFIG_SCHEMAS:
-        envvars = os.environ
-        config_var = tag.upper()[:-1] + "_CONFIG"
-        token_var = tag.upper()[:-1] + "_TOKEN"
-        # FIXME be more specific on raising error (config or data)
-        try:
-            tag_config = json.loads(envvars.get(config_var, "{}"))
-            pattern = re.compile(r"config=(.+)")
-            match = pattern.match(value)
+    value = re.sub(rf"^{tag}", "", value).strip()
 
-            markers = detect_markers(config, value)
-            value_with_config = (
-                match.group(1).split(markers["config_end"] + ":")
-                if pattern.match(value)
-                else None
+    envvars = os.environ
+    config_var = tag.upper()[:-1] + "_CONFIG"
+    token_var = tag.upper()[:-1] + "_TOKEN"
+
+    try:
+        tag_config = json.loads(envvars.get(config_var, "{}"))
+        pattern = re.compile(r"config=(.+)")
+        match = pattern.match(value)
+
+        markers = detect_markers(config, value)
+        value_with_config = (
+            match.group(1).split(markers["config_end"] + ":")
+            if pattern.match(value)
+            else None
+        )
+
+        if value_with_config and len(value_with_config) > 1:
+            config_str, value = value_with_config
+            config_str = config_str.lstrip(markers["config_start"])
+            tag_config.update(json.loads(f"{{{config_str}}}"))
+        elif value_with_config:
+            raise E2j2Exception(
+                "invalid config markers used, please place the config between the markers "
+                f"'{markers['config_start']}' and '{markers['config_end']}'"
             )
 
-            if value_with_config and len(value_with_config) > 1:
-                config_str, value = value_with_config
-                config_str = config_str.lstrip(markers["config_start"])
-                tag_config.update(json.loads("{%s}" % config_str))
-            elif value_with_config:
-                raise E2j2Exception(
-                    "invalid config markers used, please place the config between the markers '%s' and '%s'"
-                    % (markers["config_start"], markers["config_end"])
-                )
+        if token_var in envvars:
+            tag_config["token"] = (
+                tag_config["token"] if "token" in tag_config else envvars[token_var]
+            )
 
-            if token_var in envvars:
-                tag_config["token"] = (
-                    tag_config["token"] if "token" in tag_config else envvars[token_var]
-                )
+        if "token" in tag_config and tag_config["token"].startswith("file:"):
+            token_value = re.sub(r"^file:", "", tag_config["token"])
+            tag_config["token"] = file_tag.parse(token_value).strip()
 
-            if "token" in tag_config and tag_config["token"].startswith("file:"):
-                token_value = re.sub(r"^file:", "", tag_config["token"])
-                tag_config["token"] = file_tag.parse(token_value).strip()
-
-        except JSONDecodeError:
-            raise E2j2Exception("decoding JSON failed")
+    except JSONDecodeError as err:
+        raise E2j2Exception("decoding JSON failed") from err
 
+    if tag in CONFIG_SCHEMAS:
         try:
             validate(
                 instance=tag_config,
                 schema=CONFIG_SCHEMAS[tag],
-                format_checker=draft4_format_checker,
+                format_checker=Draft4Validator.FORMAT_CHECKER,
             )
-        except ValidationError:
+        except ValidationError as err:
             if config["stacktrace"]:
                 write(traceback.format_exc())
 
-            raise E2j2Exception("config validation failed")
+            raise E2j2Exception("config validation failed") from err
 
     if tag == "json:":
         tag_value = json_tag.parse(value)
@@ -169,19 +173,19 @@ def parse_tag(config, tag, value):
     elif tag == "escape:":
         tag_value = escape_tag.parse(value)
     else:
-        return None, "** ERROR: tag: %s not implemented **" % tag
+        return None, f"** ERROR: tag: {tag} not implemented **"
 
     if config["nested_tags"] and tag in NESTED_TAGS:
         try:
             for keys, item in recursive_iter(tag_value):
                 if isinstance(item, str):
-                    dpath_util.set(
+                    dpath.set(
                         tag_value,
                         list(keys),
                         resolv_vars(config, ["item"], {"item": item})["item"],
                     )
-        except Exception:
-            raise E2j2Exception("failed to resolve nested tag")
+        except Exception as err:
+            raise E2j2Exception("failed to resolve nested tag") from err
 
     return tag_config, tag_value
 
@@ -218,36 +222,39 @@ def render(config, j2file, j2vars):
             j2.comment_start_string = markers["comment_start"]
             j2.comment_end_string = markers["comment_end"]
             return j2.from_string(first_pass).render(j2vars)
-        else:
-            return first_pass
+
+        return first_pass
+
     except (UndefinedError, FilterArgumentError, TemplateSyntaxError) as err:
         exc_type, exc_value, exc_tb = sys.exc_info()
         stacktrace = traceback.format_exception(exc_type, exc_value, exc_tb)
         match = re.search(r"\sline\s(\d+)", stacktrace[-2])
-        content = "failed with error: {}".format(err)
-        content += " at line: {}".format(match.group(1)) if match else ""
-        raise E2j2Exception(content)
-    except FileNotFoundError:
-        raise E2j2Exception("Template %s not found" % filename)
+        content = f"failed with error: {err}"
+        content += f" at line: {match.group(1)}" if match else ""
+        raise E2j2Exception(content) from err
+    except FileNotFoundError as err:
+        raise E2j2Exception(f"Template {filename} not found") from err
     except Exception as err:
-        raise E2j2Exception(str(err))
+        raise E2j2Exception(err) from err
 
 
 def detect_markers(config, content):
     marker_set = MARKER_SETS[config["marker_set"]]
 
     if config["autodetect_marker_set"]:
-        config_marker = True if "config=" in content else False
-        for key, value in MARKER_SETS.items():
+        config_marker = "config=" in content
+        for value in MARKER_SETS.values():
             if config_marker:
-                if "config=" + MARKER_SETS[key]["config_start"] in content:
-                    marker_set = MARKER_SETS[key]
+                if "config=" + value["config_start"] in content:
+                    marker_set = value
+                    break
             else:
                 if (
-                    MARKER_SETS[key]["variable_start"] in content
-                    and MARKER_SETS[key]["variable_end"] in content
+                    value["variable_start"] in content
+                    and value["variable_end"] in content
                 ):
-                    marker_set = MARKER_SETS[key]
+                    marker_set = value
+                    break
 
     markers = {
         "block_start": config["block_start"]
